ShapeInstance

Struct ShapeInstance 

pub struct ShapeInstance {
Show 23 fields pub instance: f64, pub num_inst: f64, pub sides: f64, pub x: f64, pub y: f64, pub rad: f64, pub ang: f64, pub tex_zoom: f64, pub tex_ang: f64, pub r: f64, pub g: f64, pub b: f64, pub a: f64, pub r2: f64, pub g2: f64, pub b2: f64, pub a2: f64, pub border_r: f64, pub border_g: f64, pub border_b: f64, pub border_a: f64, pub thick: f64, pub additive: f64,
}
One iteration of a custom-shape (shapecode_N) per-instance loop. MD2 shape per-frame equations can mutate any of these fields and the next instance’s loop body sees the seed values fresh from the preset’s scalar block — instances do NOT carry state across each other (unlike WavePoint). Persistent state across instances lives in q* / t* channels.

instance is the 0-based loop counter; the eval seeds it (and sides + num_inst) into the context before each call so equations like ang = ang + 0.1 * instance work.

Fields

instance: f64num_inst: f64sides: f64x: f64y: f64rad: f64ang: f64tex_zoom: f64tex_ang: f64r: f64g: f64b: f64a: f64r2: f64g2: f64b2: f64a2: f64border_r: f64border_g: f64border_b: f64border_a: f64thick: f64

MD2 thick flag (drawn as bool, kept f64 to round-trip via the eval context with no extra conversions). 0 = thin outline, 1 = thick.

additive: f64

MD2 additive flag (0 = alpha blend, 1 = additive).